==> PyraUtils-0.9.3.tar.gz: PyraUtils-0.9.3/PyraUtils/service/work_wechat/CorpApi.py <==
# -*- coding: utf-8 -*-
from .AbstractApi import AbstractApi
from .CorpApiType import *


class CorpApi(AbstractApi) :
    def __init__(self, corpid, corpsecret):
        self.corpid = corpid
        self.corpsecret = corpsecret
        self.access_token = None

    def refreshAccessToken(self) :
        parms = dict(
            corpid=self.corpid,
            corpsecret=self.corpsecret,
        )
        response = self.httpCall(CORP_API_TYPE['GET_ACCESS_TOKEN'], parms)
        self.access_token = response.get('access_token')

    def getAccessToken(self) :
        if self.access_token is None:
            self.refreshAccessToken()
        return self.access_token


    def get_user_detail(self, access_token, userid):
        """
        功能： 读取成员。https://work.weixin.qq.com/api/doc/90000/90135/90196
        """
        params = dict(
            access_token=access_token,
            userid=userid
        )

        response = self.httpCall(CORP_API_TYPE['USER_GET'], params)
        return response

    def get_approval_detail(self, access_token, sp_no):
        """
        功能： 企业可通过审批应用或自建应用Secret调用本接口，根据审批单号查询企业微信“审批应用”的审批申请详情。。
        """

        params = dict(
            access_token=access_token
        )

        body = dict(
            sp_no=sp_no
        )

        response = self.httpCall(CORP_API_TYPE['APPROVAL_DETAIL'], params, req_body=body)
        return response

    def sendMessage(self, access_token, touser, agentid,  msgtype="text", safe=0, **kwargs):
        """消息发送"""
        params = dict(
            access_token=access_token
        )

        if msgtype == "text":
            msg_data = {
                "content": kwargs["msg_content"]
            }
            body = dict(
                touser=touser,
                msgtype=msgtype,
                agentid=agentid,
                safe=safe,
                text=msg_data,
                enable_duplicate_check=0,
                duplicate_check_interval=1800
            )
        elif msgtype == "markdown":
            msg_data = {
                "content": kwargs["msg_content"]
            }
            body = dict(
                touser=touser,
                msgtype=msgtype,
                agentid=agentid,
                safe=safe,
                markdown=msg_data,
                enable_duplicate_check=0,
                duplicate_check_interval=1800
            )
        elif msgtype == "textcard":
            msg_data = {
                "title" :  kwargs["msg_title"],
                "description" : kwargs["msg_content"],
                "url" : kwargs["msg_url"],
                "btntxt":"详情"
            }
            body = dict(
                touser=touser,
                msgtype=msgtype,
                agentid=agentid,
                textcard=msg_data,
                enable_duplicate_check=0,
                duplicate_check_interval=1800
            )
        elif msgtype == "template_card":
            pass
        response = self.httpCall(CORP_API_TYPE['MESSAGE_SEND'], params, req_body=body)
        return response

==> PyraUtils-0.9.9.tar.gz: PyraUtils-0.9.9/PyraUtils/service/work_wechat/CorpApi.py <==
# -*- coding: utf-8 -*-

from .AbstractApi import AbstractApi
from .CorpApiType import *


class CorpApi(AbstractApi) :
    def __init__(self, corpid, corpsecret):
        self.corpid = corpid
        self.corpsecret = corpsecret
        self.access_token = None

    def refreshAccessToken(self) :
        parms = dict(
            corpid=self.corpid,
            corpsecret=self.corpsecret,
        )
        response = self.httpCall(CORP_API_TYPE['GET_ACCESS_TOKEN'], parms)
        self.access_token = response.get('access_token')

    def getAccessToken(self) :
        if self.access_token is None:
            self.refreshAccessToken()
        return self.access_token

    def get_user(self, access_token, userid):
        """
        功能： 读取成员。https://work.weixin.qq.com/api/doc/90000/90135/90196
        """
        params = dict(
            access_token=access_token,
            userid=userid
        )

        response = self.httpCall(CORP_API_TYPE['USER_GET'], params)
        return response
    
    def get_user_list_id(self, access_token):
        """
        功能： 获取成员ID列表。https://developer.work.weixin.qq.com/document/path/96067
        """
        params = dict(
            access_token=access_token
        )

        response = self.httpCall(CORP_API_TYPE['USER_LIST_ID'], params)
        return response

    def get_userid_by_email(self, access_token, email, email_type=1):
        """
        功能： 邮箱获取userid。

        https://developer.work.weixin.qq.com/document/path/95895

        email_type: 邮箱类型：1-企业邮箱（默认）, 2-个人邮箱
        """
        params = dict(
            access_token=access_token
        )

        body = dict(
            email=email,
            email_type=email_type
        )

        response = self.httpCall(CORP_API_TYPE['USERID_BY_EMAIL_POST'], params, req_body=body)
        return response


    def get_approval_detail(self, access_token, sp_no):
        """
        功能： 企业可通过审批应用或自建应用Secret调用本接口，根据审批单号查询企业微信“审批应用”的审批申请详情。。
        """

        params = dict(
            access_token=access_token
        )

        body = dict(
            sp_no=sp_no
        )

        response = self.httpCall(CORP_API_TYPE['APPROVAL_DETAIL'], params, req_body=body)
        return response

    def sendMessage(self, access_token, touser, agentid,  msgtype="text", safe=0, **kwargs):
        """消息发送"""
        params = dict(
            access_token=access_token
        )

        if msgtype == "text":
            msg_data = {
                "content": kwargs["msg_content"]
            }
            body = dict(
                touser=touser,
                msgtype=msgtype,
                agentid=agentid,
                safe=safe,
                text=msg_data,
                enable_duplicate_check=0,
                duplicate_check_interval=1800
            )
        elif msgtype == "markdown":
            msg_data = {
                "content": kwargs["msg_content"]
            }
            body = dict(
                touser=touser,
                msgtype=msgtype,
                agentid=agentid,
                safe=safe,
                markdown=msg_data,
                enable_duplicate_check=0,
                duplicate_check_interval=1800
            )
        elif msgtype == "textcard":
            msg_data = {
                "title" :  kwargs["msg_title"],
                "description" : kwargs["msg_content"],
                "url" : kwargs["msg_url"],
                "btntxt":"详情"
            }
            body = dict(
                touser=touser,
                msgtype=msgtype,
                agentid=agentid,
                textcard=msg_data,
                enable_duplicate_check=0,
                duplicate_check_interval=1800
            )
        elif msgtype == "template_card":
            pass
        response = self.httpCall(CORP_API_TYPE['MESSAGE_SEND'], params, req_body=body)
        return response
